[Libreoffice-commits] .: 2 commits - bin/distro-install-desktop-integration l10ntools/source

Petr Mladek pmladek at kemper.freedesktop.org
Tue Jun 19 04:53:03 PDT 2012


 bin/distro-install-desktop-integration |    4 ++++
 l10ntools/source/localize.cxx          |   14 +++++++-------
 2 files changed, 11 insertions(+), 7 deletions(-)

New commits:
commit aab6aba1482c56823b9fcc9a5f0ed0d131d37af0
Author: Petr Mladek <pmladek at suse.cz>
Date:   Tue Jun 19 13:50:55 2012 +0200

    fix help localization from source tarballs
    
    localize tool need to get strings also from src directory
    
    Change-Id: If8e94198002888d1fcf9b0b0416b7b5dcaa46386

diff --git a/bin/distro-install-desktop-integration b/bin/distro-install-desktop-integration
index 3727f83..99f9c60 100755
--- a/bin/distro-install-desktop-integration
+++ b/bin/distro-install-desktop-integration
@@ -168,6 +168,10 @@ add_wrapper libreoffice    soffice ""            "libreoffice" "libreoffice-star
 add_wrapper loffice        soffice ""            "libreoffice" ""                                "gid_Module_Root_Brand"
 add_wrapper unopkg         unopkg  ""            "unopkg"      ""                                "gid_Module_Root_Brand"
 
+# there are two more desktop files for optional filters
+test -f $DESTDIR/gid_Module_Optional_Binfilter && echo "$PREFIXDIR/share/applications/libreoffice-binfilter.desktop" >>"$DESTDIR/gid_Module_Optional_Binfilter"
+test -f $DESTDIR/gid_Module_Optional_Xsltfiltersamples && echo "$PREFIXDIR/share/applications/libreoffice-xsltfilter.desktop" >>"$DESTDIR/gid_Module_Optional_Xsltfiltersamples"
+
 # $PREFIXDIR/bin/ooffice symlink is necessary by java UNO components to find
 # the UNO installation using $PATH, see
 # http://udk.openoffice.org/common/man/spec/transparentofficecomponents.html


More information about the Libreoffice-commits mailing list
diff --git a/l10ntools/source/localize.cxx b/l10ntools/source/localize.cxx
index 2279dd9..81d4875 100644
--- a/l10ntools/source/localize.cxx
+++ b/l10ntools/source/localize.cxx
@@ -367,15 +367,15 @@ bool excludeDirectory(rtl::OUString const & directory) {
 
 /// Handle one directory in the hierarchy.
 ///
 /// Ignores symlinks and instead explicitly descends into clone/*, as the
 /// Cygwin symlinks are not supported by osl::Directory on Windows.
 ///
 /// @param url the absolute file URL of this directory
 ///
 /// @param level 0 if this is either the root directory that contains the
 /// projects or one of the clone/* directories that contain the additional
 /// projects; -1 if this is the clone directory; 1 if this is a project
 /// directory; 2 if this is a directory inside a project
 ///
 /// @param project the name of the project (empty and ignored if level <= 0)
 ///
@@ -411,7 +411,7 @@ void handleDirectory(
             throw false; //TODO
         }
         switch (level) {
-        case -1: // the clone directory
+        case -1: // the clone or src directory
             if (stat.getFileType() == osl::FileStatus::Directory) {
                 handleDirectory(
                     stat.getFileURL(), 0, rtl::OUString(), rtl::OUString());
@@ -423,7 +423,7 @@ void handleDirectory(
                     handleDirectory(
                         stat.getFileURL(), 1, stat.getFileName(),
                         rtl::OUString());
-                } else if ( stat.getFileName() == "clone" )
+                } else if ( stat.getFileName() == "clone" || stat.getFileName() == "src" )
                 {
                     handleDirectory(
                         stat.getFileURL(), -1, rtl::OUString(),
@@ -367,15 +367,15 @@ bool excludeDirectory(rtl::OUString const & directory) {
 /// Handle one directory in the hierarchy.
 ///
-/// Ignores symlinks and instead explicitly descends into clone/*, as the
-/// Cygwin symlinks are not supported by osl::Directory on Windows.
+/// Ignores symlinks and instead explicitly descends into clone/* or src/*,
+/// as the Cygwin symlinks are not supported by osl::Directory on Windows.
 ///
 /// @param url the absolute file URL of this directory
@@ -367,15 +367,15 @@ bool excludeDirectory(rtl::OUString const & directory) {
 ///
 /// @param level 0 if this is either the root directory that contains the
-/// projects or one of the clone/* directories that contain the additional
-/// projects; -1 if this is the clone directory; 1 if this is a project
-/// directory; 2 if this is a directory inside a project
+/// projects or one of the clone/* or src/* directories that contain the
+/// additional projects; -1 if this is the clone directory; 1 if this
+/// is a project directory; 2 if this is a directory inside a project
 ///
 /// @param project the name of the project (empty and ignored if level <= 0)
commit c7b98f2fd8d892cd63503bc053ba533fd5e7ca02
Author: Petr Mladek <pmladek at suse.cz>
Date:   Tue Jun 19 12:28:32 2012 +0200

    put the two new optinal desktop files into right file lists
    
    Change-Id: I9e62bb0c14f2ba0d481cb4e926935af2394a652d
